@@ -69,7 +69,7 @@ static gchar helpmsg[] = {
 	"  lxterminal [Options...] - LXTerminal is a terminal emulator\n\n"
 	"Options:\n"
 	"  -e, --command=STRING             Execute the argument to this option inside the terminal\n"
-	"  -t, --title=STRING               Set the terminal's title\n"
+	"  -t, -T, --title=STRING               Set the terminal's title\n"
 	"  --working-directory=DIRECTORY    Set the terminal's working directory\n"
 	"  --geometry=GEOMETRY              X geometry specification (see \"X\" man page), can be specified once per window to be opened.\n"
 };
@@ -85,37 +85,43 @@ static GtkActionEntry menus[] =
 	{ "Help", NULL, N_("_Help") }
 };
 
-#define MENUBAR_MENUITEM_COUNT 12
-//#define MENUBAR_MENUITEM_COUNT 13
+#define MENUBAR_MENUITEM_COUNT 14
+//#define MENUBAR_MENUITEM_COUNT 15
 static GtkActionEntry menu_items[] =
 {
-	{ "File_NewWindow", GTK_STOCK_ADD, N_("_New Window"), NEW_WINDOW_ACCEL, "New Window", G_CALLBACK(terminal_newwindow)},
-	{ "File_NewTab", GTK_STOCK_ADD, N_("_New Tab"), NEW_TAB_ACCEL, "New Tab", G_CALLBACK(terminal_newtab)},
+	{ "File_NewWindow", GTK_STOCK_ADD, N_("New _Window"), NEW_WINDOW_ACCEL, "New Window", G_CALLBACK(terminal_newwindow)},
+	{ "File_NewTab", GTK_STOCK_ADD, N_("New _Tab"), NEW_TAB_ACCEL, "New Tab", G_CALLBACK(terminal_newtab)},
 	{ "File_Sep1", NULL, "Sep" },
 	{ "File_CloseTab", GTK_STOCK_CLOSE, N_("_Close Tab"), CLOSE_TAB_ACCEL, "Close Tab", G_CALLBACK(terminal_closetab)},
 	{ "File_Quit", GTK_STOCK_QUIT, N_("_Quit"), QUIT_ACCEL, "Quit", G_CALLBACK(gtk_main_quit)},
-	{ "Edit_Copy", GTK_STOCK_COPY, N_("_Copy"), COPY_ACCEL, "Copy", G_CALLBACK(terminal_copy)},
+	{ "Edit_Copy", GTK_STOCK_COPY, N_("Cop_y"), COPY_ACCEL, "Copy", G_CALLBACK(terminal_copy)},
 	{ "Edit_Paste", GTK_STOCK_PASTE, N_("_Paste"), PASTE_ACCEL, "Paste", G_CALLBACK(terminal_paste)},
 	{ "Edit_Sep1", NULL, "Sep" },
-	{ "Edit_Preferences", GTK_STOCK_EXECUTE, N_("_Preferences"), NULL, "Preferences", G_CALLBACK(lxterminal_preferences_dialog)},
+	{ "Edit_Preferences", GTK_STOCK_EXECUTE, N_("Preference_s"), NULL, "Preferences", G_CALLBACK(lxterminal_preferences_dialog)},
 //	{ "View_CharacterEncoding", NULL, N_("_Character Encoding"), NULL, "Character Encoding", NULL},
-	{ "Tabs_PreviousTab", NULL, N_("_Previous Tab"), PREVIOUS_TAB_ACCEL, "Previous Tab", G_CALLBACK(terminal_prevtab)},
-	{ "Tabs_NextTab", NULL, N_("_Next Tab"), NEXT_TAB_ACCEL, "Next Tab", G_CALLBACK(terminal_nexttab)},
-	{ "Help_About", NULL, N_("_About"), NULL, "About", G_CALLBACK(terminal_about)}
+	{ "Tabs_PreviousTab", GTK_STOCK_GO_BACK, N_("Pre_vious Tab"), PREVIOUS_TAB_ACCEL, "Previous Tab", G_CALLBACK(terminal_prevtab)},
+	{ "Tabs_NextTab", GTK_STOCK_GO_FORWARD, N_("Ne_xt Tab"), NEXT_TAB_ACCEL, "Next Tab", G_CALLBACK(terminal_nexttab)},
+	{ "Tabs_MoveTabLeft", NULL, N_("Move Tab _Left"), MOVE_TAB_LEFT_ACCEL, "Move Tab Left", G_CALLBACK(terminal_movetableft)},
+	{ "Tabs_MoveTabRight", NULL, N_("Move Tab _Right"), MOVE_TAB_RIGHT_ACCEL, "Move Tab Right", G_CALLBACK(terminal_movetabright)},
+	{ "Help_About", GTK_STOCK_ABOUT, N_("_About"), NULL, "About", G_CALLBACK(terminal_about)}
 };
 
-#define VTE_MENUITEM_COUNT 10
+#define VTE_MENUITEM_COUNT 14
 static GtkActionEntry vte_menu_items[] =
 {
 	{ "VTEMenu", NULL, "VTEMenu" },
-	{ "NewWindow", GTK_STOCK_ADD, N_("_New Window"), NULL, "New Window", G_CALLBACK(terminal_newwindow)},
-	{ "NewTab", GTK_STOCK_ADD, N_("_New Tab"), NULL, "New Tab", G_CALLBACK(terminal_newtab)},
+	{ "NewWindow", GTK_STOCK_ADD, N_("New _Window"), NULL, "New Window", G_CALLBACK(terminal_newwindow)},
+	{ "NewTab", GTK_STOCK_ADD, N_("New _Tab"), NULL, "New Tab", G_CALLBACK(terminal_newtab)},
 	{ "Sep1", NULL, "Sep" },
-	{ "Copy", GTK_STOCK_COPY, N_("_Copy"), NULL, "Copy", G_CALLBACK(terminal_copy)},
+	{ "Copy", GTK_STOCK_COPY, N_("Cop_y"), NULL, "Copy", G_CALLBACK(terminal_copy)},
 	{ "Paste", GTK_STOCK_PASTE, N_("_Paste"), NULL, "Paste", G_CALLBACK(terminal_paste)},
 	{ "Sep2", NULL, "Sep" },
-	{ "Preferences", GTK_STOCK_EXECUTE, N_("_Preferences"), NULL, "Preferences", G_CALLBACK(lxterminal_preferences_dialog)},
+	{ "Preferences", GTK_STOCK_EXECUTE, N_("Preference_s"), NULL, "Preferences", G_CALLBACK(lxterminal_preferences_dialog)},
 	{ "Sep3", NULL, "Sep" },
+	{ "PreviousTab", GTK_STOCK_GO_BACK, N_("Pre_vious Tab"), NULL, "Previous Tab", G_CALLBACK(terminal_prevtab)},
+	{ "NextTab", GTK_STOCK_GO_FORWARD, N_("Ne_xt Tab"), NULL, "Next Tab", G_CALLBACK(terminal_nexttab)},
+	{ "Tabs_MoveTabLeft", NULL, N_("Move Tab _Left"), NULL, "Move Tab Left", G_CALLBACK(terminal_prevtab)},
+	{ "Tabs_MoveTabRight", NULL, N_("Move Tab _Right"), NULL, "Move Tab Right", G_CALLBACK(terminal_nexttab)},
 	{ "CloseTab", GTK_STOCK_CLOSE, N_("_Close Tab"), NULL, "Close Tab", G_CALLBACK(terminal_closetab)}
 };
 
@@ -355,6 +361,40 @@ void terminal_prevtab_accel(gpointer data, guint action, GtkWidget *item)
 	terminal_prevtab(NULL, data);
 }
 
+/* direction: -1=left 1=right */
+void terminal_movetab(GtkAction *action, gpointer data, gint direction)
+{
+	LXTerminal *terminal = (LXTerminal *)data;
+	GtkNotebook *notebook = GTK_NOTEBOOK(terminal->notebook);
+	gint curPageNum = gtk_notebook_get_current_page( notebook );
+
+	gtk_notebook_reorder_child(
+		notebook,
+		gtk_notebook_get_nth_page(notebook, curPageNum),
+		curPageNum + direction
+		);
+}
+
+void terminal_movetableft(GtkAction *action, gpointer data)
+{
+	terminal_movetab(action, data, -1);
+}
+
+void terminal_movetableft_accel(gpointer data, guint action, GtkWidget *item)
+{
+	terminal_movetableft(NULL, data);
+}
+
+void terminal_movetabright(GtkAction *action, gpointer data)
+{
+	terminal_movetab(action, data, 1);
+}
+
+void terminal_movetabright_accel(gpointer data, guint action, GtkWidget *item)
+{
+	terminal_movetabright(NULL, data);
+}
+
 void terminal_closetab_accel(gpointer data, guint action, GtkWidget *item)
 {
 	terminal_closetab(NULL, data);
@@ -807,6 +847,12 @@ void lxterminal_accelerator_init(LXTerminal *terminal)
 	gtk_accelerator_parse(PREVIOUS_TAB_ACCEL, &key, &mods);
 	gtk_accel_group_connect(terminal->menubar->accel_group, key, mods, GTK_ACCEL_LOCKED, g_cclosure_new_swap(G_CALLBACK(terminal_prevtab_accel), terminal, NULL));
 
+	gtk_accelerator_parse(MOVE_TAB_LEFT_ACCEL, &key, &mods);
+	gtk_accel_group_connect(terminal->menubar->accel_group, key, mods, GTK_ACCEL_LOCKED, g_cclosure_new_swap(G_CALLBACK(terminal_movetableft_accel), terminal, NULL));
+
+	gtk_accelerator_parse(MOVE_TAB_RIGHT_ACCEL, &key, &mods);
+	gtk_accel_group_connect(terminal->menubar->accel_group, key, mods, GTK_ACCEL_LOCKED, g_cclosure_new_swap(G_CALLBACK(terminal_movetabright_accel), terminal, NULL));
+
 	gtk_window_add_accel_group(GTK_WINDOW(terminal->mainw), terminal->menubar->accel_group);
 }
 
@@ -900,11 +946,11 @@ LXTerminal *lxterminal_init(LXTermWindow *lxtermwin, gint argc, gchar **argv, Se
 			} else if (strncmp(argv[i],"--title=", 8)==0) {
 				title = argv[i]+8;
 				continue;
-			} else if ((strcmp(argv[i],"--title")==0||strcmp(argv[i],"-t")==0)&&(i+1<argc)) {
+			} else if ((strcmp(argv[i],"--title")==0||strcmp(argv[i],"-t")==0||strcmp(argv[i],"-T")==0)&&(i+1<argc)) {
 				title = argv[++i];
 				continue;
 			} else if (strncmp(argv[i],"--working-directory=", 20)==0) {
-				workdir = argv[i]+20;
+				workdir = g_strdup(argv[i]+20);
 				continue;
 			} else if (strncmp(argv[i],"--geometry=", 11)==0) {
 				sscanf(argv[i]+11, "%dx%d", &cols, &rows);
@@ -949,7 +995,7 @@ LXTerminal *lxterminal_init(LXTermWindow *lxtermwin, gint argc, gchar **argv, Se
 	terminal->box = gtk_vbox_new(FALSE, 1);
 	gtk_container_add(GTK_CONTAINER(terminal->mainw), terminal->box);
 
-	/* create menuar */
+	/* create menubar */
 	terminal->menubar = menubar_init(terminal);
 	gtk_box_pack_start(GTK_BOX(terminal->box), terminal->menubar->menu, FALSE, TRUE, 0);
 
@@ -966,7 +1012,7 @@ LXTerminal *lxterminal_init(LXTermWindow *lxtermwin, gint argc, gchar **argv, Se
 	g_signal_connect(terminal->notebook, "switch-page", G_CALLBACK(terminal_switch_tab), terminal);
 	gtk_box_pack_start(GTK_BOX(terminal->box), terminal->notebook, TRUE, TRUE, 0);
 
-	workdir = (!workdir) ? g_get_current_dir() : NULL;
+	if ( ! workdir) workdir = g_get_current_dir();
 	term = terminal_new(terminal, _("LXTerminal"), workdir, NULL, cmd);
 	g_free(workdir);
 
@@ -1019,7 +1065,7 @@ int main(gint argc, gchar** argv)
 				continue;
 			} else if (strncmp(argv[i],"--title=", 8)==0) {
 				continue;
-			} else if ((strcmp(argv[i],"--title")==0||strcmp(argv[i],"-t")==0)&&(i+1<argc)) {
+			} else if ((strcmp(argv[i],"--title")==0||strcmp(argv[i],"-t")==0||strcmp(argv[i],"-T")==0)&&(i+1<argc)) {
 				i++;
 				continue;
 			} else if (strncmp(argv[i],"--working-directory=", 20)==0) {
