@@ -26,14 +26,24 @@ typedef struct {
 
 typedef struct {
 	GtkWidget *box;
-	GtkWidget *font_box;
 	GtkWidget *font_label;
 	GtkWidget *font_button;
-	GtkWidget *selchars_box;
 	GtkWidget *selchars_label;
 	GtkWidget *selchars_entry;
+	GtkWidget *bgcolor_label;
+	GtkWidget *bgcolor_entry;
+	GtkWidget *fgcolor_label;
+	GtkWidget *fgcolor_entry;
+	GtkWidget *bgtransparent_label;
+	GtkWidget *bgtransparent_checkbox;
+	GtkWidget *scrollback_label;
+	GtkWidget *scrollback_entry;
+	GtkWidget *tabpos_label;
+	GtkWidget *tabpos_combobox;
+	GtkWidget *disablef10_label;
+	GtkWidget *disablef10_checkbox;
 } PreferGeneral;
 
-void lxterminal_preferences_dialog(LXTerminal *terminal, guint action, GtkWidget *item);
+void lxterminal_preferences_dialog(GtkAction *action, gpointer data);
 
 #endif
