@@ -47,6 +47,13 @@ void setting_save(Setting *setting)
 	/* push settings to GKeyFile */
 	g_key_file_set_string(setting->keyfile, "general", "fontname", setting->fontname);
 	g_key_file_set_string(setting->keyfile, "general", "selchars", setting->selchars);
+	g_key_file_set_string(setting->keyfile, "general", "bgcolor", setting->bgcolor);
+	g_key_file_set_integer(setting->keyfile, "general", "bgalpha", setting->bgalpha);
+	g_key_file_set_string(setting->keyfile, "general", "fgcolor", setting->fgcolor);
+	g_key_file_set_boolean(setting->keyfile, "general", "bgtransparent", setting->bgtransparent);
+	g_key_file_set_string(setting->keyfile, "general", "tabpos", setting->tabpos);
+	g_key_file_set_integer(setting->keyfile, "general", "scrollback", (gint)setting->scrollback);
+	g_key_file_set_boolean(setting->keyfile, "general", "disablef10", setting->disablef10);
 
 	/* generate config data */
 	file_data = g_key_file_to_data(setting->keyfile, NULL, NULL);
@@ -78,6 +85,13 @@ Setting *load_setting_from_file(const char *filename)
 		/* general setting */
 		setting->fontname = g_key_file_get_string(setting->keyfile, "general", "fontname", NULL);
 		setting->selchars = g_key_file_get_string(setting->keyfile, "general", "selchars", NULL);
+		setting->bgcolor = g_key_file_get_string(setting->keyfile, "general", "bgcolor", NULL);
+		setting->bgalpha = g_key_file_get_integer(setting->keyfile, "general", "bgalpha", NULL);
+		setting->fgcolor = g_key_file_get_string(setting->keyfile, "general", "fgcolor", NULL);
+		setting->bgtransparent = g_key_file_get_boolean(setting->keyfile, "general", "bgtransparent", NULL);
+		setting->tabpos = g_key_file_get_string(setting->keyfile, "general", "tabpos", NULL);
+		setting->scrollback = (glong)g_key_file_get_integer(setting->keyfile, "general", "scrollback", NULL);
+		setting->disablef10 = g_key_file_get_boolean(setting->keyfile, "general", "disablef10", NULL);
 	}
 
 setting_default:
@@ -88,5 +102,26 @@ setting_default:
 	if (!setting->selchars)
 		setting->selchars = g_strdup("-A-Za-z0-9,./?%&#:_");
 
+	if (!setting->bgcolor)
+		setting->bgcolor = g_strdup("#000000");
+	
+	if (!setting->bgalpha)
+		setting->bgalpha = (guint16) 0xDDDD;
+
+	if (!setting->fgcolor)
+		setting->fgcolor = g_strdup("#aaaaaa");
+
+	if (!setting->bgtransparent)
+		setting->bgtransparent = FALSE;
+
+	if (!setting->tabpos)
+		setting->tabpos = g_strdup("top");
+
+	if (!setting->scrollback)
+		setting->scrollback = (glong)1000;
+
+	if (!setting->disablef10)
+		setting->disablef10 = FALSE;
+
 	return setting;
 }
