@@ -4,6 +4,13 @@
 typedef struct _setting {
 	char *fontname;
 	char *selchars;
+	char *bgcolor;
+	char *fgcolor;
+	char *tabpos;
+	guint16 bgalpha;
+	glong scrollback;
+	gboolean disablef10;
+	gboolean bgtransparent;
 	GKeyFile *keyfile;
 } Setting;
 
